package easik;

import java.util.regex.*;
import java.util.Collection;

/**
 * Various useful small utility functions that are used in multiple places
 * within Easik.  Commonly-used algorithms in Easik are good candidates for
 * moving to this file.
 */
public class EasikTools {
	private static final Pattern endDigits = Pattern.compile("(\\d+)$");
	/**
	 * Takes a name, such as "name" or "name5", and increments or adds a number
	 * as appropriate.  For example, passing "name" would return "name2", while
	 * "name0" would return "name1".
	 */
	public static String incrementName (String name) {
		Matcher m = endDigits.matcher(name);
		if (m.find())
			return m.replaceFirst("" + (Integer.parseInt(m.group(1)) + 1));
		else // No digits, so we have something like blah, so change it to blah2
			return name + 2;
	}

	/**
	 * Joins strings together on a delimiter, like Perl's join function or
	 * PHP's implode function.
	 *
	 * @param delimiter the delimiter to join the pieces with
	 * @param pieces the strings to join
	 * @return the joined string
	 */
	public static String join(String delimiter, Object... pieces) {
		StringBuilder result = new StringBuilder();
		result.append("" + pieces[0]);
		for (int i = 1; i < pieces.length; i++) {
			result.append(delimiter);
			result.append("" + pieces[i]);
		}

		return result.toString();
	}
	/**
	 * Just like join(), but takes any sort of String Collection (LinkedList,
	 * ArrayList, Set, etc.).
	 */
	public static String join(String delimiter, Collection<?> pieces) {
		return join(delimiter, pieces.toArray());
	}
//	public static String join(String delimiter, String[] pieces)
}
