package easik.database.types;

import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a BLOB ("B"inary "L"arge "Ob"ject) SQL data type.  A
 * BLOB is used to store arbitrary binary data.  Note that implementations vary
 * significantly: this will be mapped to the nearly-equivelant BYTEA type for
 * PostgreSQL, which can require special handling.  It is best to look up how
 * your database handles BLOB/BYTEA/binary data types before using this BLOB
 * type.
 */
public class Blob extends Type {
	public String toString() { return "BLOB"; }

	public boolean verifyInput(String input){ return true; }

	public int getSqlType() { return Types.BLOB; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setString(col, value);
	}
}
