package easik.database.types;

import java.util.Map;
import java.util.Collections;
import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a user-provided SQL data type.  No checking or automatic
 * database type conversion will be performed on this type--users specifying a
 * custom type are expected to provide a valid custom type.
 */
public class Custom extends Type {
	private String custom;
	public Custom(String type) {
		custom = type;
	}
	public String toString() { return custom; }

	/**
	 * Returns the custom SQL type signature this Custom object was created with.
	 */
	public String getCustom() { return custom; }


	public boolean verifyInput(String input){ return true; }

	/**
	 * Returns the attributes of this object.  For a Custom type,
	 * this is just the entire type signature as a "custom" attribute key.
	 */
	public Map<String, String> attributes() {
		return Collections.singletonMap("custom", custom);
	}
	/**
	 * Recreates the object from the attributes returned by attributes().
	 */
	public Custom(Map<String, String> attr) {
		this(attr.get("custom"));
	}

	public int getSqlType(){ return Types.OTHER; }//FIXME??

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setString(col, value);
	}
}
