package easik.database.types;

import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing a DOUBLE PRECISION SQL data type.  This is a fairly common type
 * typically with a range of about 1e-307 to 1e+308, and a precision of at least 15 digits.
 * See also FLOAT, for less precise floating point numbers, and DECIMAL for fixed-precision
 * floating point values.  In standard SQL, this is essentially a FLOAT(53).
 */
public class DoublePrecision extends Type {
	public String toString() { return "DOUBLE PRECISION"; }

	public boolean verifyInput(String input){
		return input.matches("^([+−]?)(?=\\d|\\.\\d)\\d*(\\.\\d*)?([Ee]([+−]?\\d+))?$");
	}

	public int getSqlType(){ return Types.DOUBLE; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setDouble(col, Double.parseDouble(value));
	}
}
