package easik.database.types;

import java.sql.Types;
import java.sql.PreparedStatement;
import java.sql.SQLException;

/**
 * A class representing an INTEGER SQL data type.  An INTEGER can contain values
 * from -2^31 to 2^31-1.  See also SmallInt and BigInt.  This class should really
 * be named Integer, as that is the standard type, but that interferes with java's
 * built-in Integer class.
 */
public class Int extends Type {
	public String toString() { return "INTEGER"; }

	public boolean verifyInput(String input){
		return input.matches("^[-+]?\\d{1,10}$");
	}

	public int getSqlType(){ return Types.INTEGER; }

	public void bindValue(PreparedStatement ps, int col, String value) throws SQLException{
		ps.setInt(col, Integer.parseInt(value));
	}
}
