package easik.graph;

import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.awt.geom.Line2D;
import java.util.ArrayList;
import java.util.List;

import org.jgraph.graph.*;
import org.jgraph.util.Spline2D;

/**
 * A routing algorithm that routes multiple edges in parallel, but separated.
 * We extend JGraph's ParallelEdgeRouter to also handle separating parallel
 * loops.
 */
public class EdgeRouter extends org.jgraph.util.ParallelEdgeRouter {
	/**
	 * Singleton to reach parallel edge router
	 */
	protected static final EdgeRouter sharedInstance = new EdgeRouter();

	/**
	 * Getter for singleton managing parallel edges
	 * 
	 * @return ParallelEdgeRouter for parallel edges
	 */
	public static EdgeRouter getSharedInstance() {
		return sharedInstance;
	}

	/**
	 * Calculates intermediate points for multiple loops.  This is the same
	 * algorithm used by DefaultEdge.LoopRouting, but we scale the loop box for
	 * parallel self-referencing edges.
	 */
	public List routeLoop(GraphLayoutCache cache, EdgeView edge) {
		CellView sourceNode = edge.getSource();
		List newPoints = new ArrayList();
		newPoints.add(sourceNode);
		CellView sourceParent = sourceNode != null ? sourceNode.getParentView() : edge.getSourceParentView();

		Object[] edges = DefaultGraphModel.getEdgesBetween(cache.getModel(), sourceNode.getCell(), sourceNode.getCell(), true);
		int position = 0;
		if (edges != null) {
			for (int i = 0; i < edges.length; i++) {
				if (edges[i] == edge.getCell()) {
					position = i;
					break;
				}
			}
		}

		if (sourceParent != null) {
			Point2D from = AbstractCellView.getCenterPoint(sourceParent);
			Rectangle2D rect = sourceParent.getBounds();
			double posWidthFactor = 1.25 + 0.75*position;
			double posHeightFactor = 1.5 + position;
			double width = rect.getWidth();
			double height2 = rect.getHeight() / 2;
			double loopWidth = Math.min(20, Math.max(10, width / 8));
			double loopHeight = Math.min(30, Math.max(12, Math.max(loopWidth + 4, height2 / 2)));
		   	loopWidth *= posWidthFactor;
			loopHeight *= posHeightFactor;
			newPoints.add(edge.getAttributes().createPoint(
					from.getX() - loopWidth,
					from.getY() - height2 - loopHeight * 1.0));
			double midpointY = from.getY() - height2 - 1.5*loopHeight;
			newPoints.add(edge.getAttributes().createPoint(from.getX(), midpointY));
			newPoints.add(edge.getAttributes().createPoint(
					from.getX() + loopWidth,
					from.getY() - height2 - loopHeight * 1.0));
			newPoints.add(edge.getTarget());

			return newPoints;
		}
		return null;
	}

	/**
	 * Overridden to fix the label positioning.  ParallelEdgeRouter gets this
	 * a bit wrong, so instead we construct the spline, get the mid-point, and
	 * then get the distance from the start-to-end line segment to the point
	 */
	/*
	 * TODO -- this doesn't work properly, and the labels aren't *that* far off, so
	 * it's left unfinished for now.
	 *
	public List routeEdge(GraphLayoutCache cache, EdgeView edge) {
		List points = super.routeEdge(cache, edge);

		Point2D labelPos = edge.getLabelPosition();
		if (labelPos != null) {
			double t = labelPos.getX() / GraphConstants.PERMILLE;
			Point2D[] pts = new Point2D[points.size()];
			for (int i = 0; i < pts.length; i++) {
				Object p = points.get(i);
				if (p instanceof CellView)
					pts[i] = AbstractCellView.getCenterPoint((CellView) p);
				else
					pts[i] = (Point2D) points.get(i);

			}
			Spline2D edgeSpline = new Spline2D(pts);
			double[] splinePt = edgeSpline.getPoint(t);
			double dist = new Line2D.Double(pts[0], pts[pts.length-1]).ptLineDist(splinePt[0], splinePt[1]);
			GraphConstants.setLabelPosition(edge.getAllAttributes(), new Point2D.Double(labelPos.getX(), dist));
		}

		return points;
	}*/
}
