package easik.overview.vertex;



import easik.DocumentInfo;
import easik.ui.ViewFrame;
import easik.overview.Overview;
import easik.view.View;


/**
 * An entity node represents a table in a database. It has a name,
 * attributes, and unique keys. This class keeps track of all these
 * elements. 
 * 
 * @author Rob Fletcher 2005
 * @author Kevin Green 2006
 * @version 2006-06-21 Kevin Green
 */
public class ViewNode extends OverviewVertex {

	/** The view represented by this node */
	private ViewFrame _theFrame;

	/**
	 * Creates a new entity node with the name provided.
	 * 
	 * @param nodeName The name of the new node
	 */
	public ViewNode( String nodeName, ViewFrame inFrame ) {
			super();
			_theFrame = inFrame;
			_theFrame.getView().getDocInfo().setName(nodeName);
			_theFrame.assignNode(this);
			_thumb = null;
	}
	
	/**
	 * Creates a new enity node with the name provided.
	 * Stores visual representation information.
	 * 
	 * @param nodeName Name of the new node
	 * @param x X Coordinate of the new node
	 * @param y Y Coordinate of the new node
	 */
	public ViewNode( String nodeName, int x, int y, ViewFrame inFrame ) {
			super(nodeName, x, y);
			_theFrame = inFrame;
			_theFrame.getView().getDocInfo().setName(nodeName);
			_theFrame.assignNode(this);
			_thumb = null;
	}

	/**
	 * Accessor method for Sketch Frame represented by this node
	 *
	 * @return The View Frame represented by this node
	 */
	public ViewFrame getFrame(){
		return _theFrame;
	}

	/**
	 * Accessor method for the view represented by this mode. Alias for _theFrame.getView();
	 * @return The view represented by this node.
	 */
	public View getView(){
		return _theFrame.getView();
	}

    /**
     * Changes the ViewNode's name.  Also updates the name in the Overview.
     * The actual name, if it already exists, might have a number added and/or
     * incremented.
     * 
     * @param name the new name (which might be incremented)
     */
    public void setName(String name) {
        // If name is already the same, do not try to update - avoids improper incrementation
        if(_name != name){
            Overview ov = _theFrame.getView().getOverview();
            String oldName = _name;

            // update node mapping in overview
            name = ov.viewRenamed(this, oldName, name);
            // update node name in its document info
            _theFrame.getView().getDocInfo().setName(name);
            // update name stored here
            _name = name;
        }
    }

    /** 
     * Refreshes the name stored locally to match what is in this sketch's document information
     */
    public void updateName(){
        DocumentInfo d = _theFrame.getView().getDocInfo();
        if(_name != d.getName()){
            _name = d.getName();
        }   
    }

	/**
	 * Getter method for the overview in which this node exists. Simply calls _theFrame.getView().getOverview().
	 * @return The overview in which this node exists.
	 */
	public Overview getOverview(){
		return _theFrame.getView().getOverview();
	}
}
