package easik.sketch.edge;

import easik.sketch.constraint.Constraint;
import easik.sketch.vertex.EntityNode;

import org.jgraph.graph.DefaultEdge;
import org.jgraph.graph.GraphConstants;
import org.jgraph.graph.AttributeMap;

/**
 *	The GuideEdge is a directed edge which is used only as a visual aid to
 *	the graph drawer. It is rendered differently than the traditional edge, 
 *	and allows constraints to show which entities it applies to. Technically
 *	it should point to arrows, not nodes, but that might be a bit tricky.
 *
 * @author Rob Fletcher 2005
 * @author Kevin Green 2006
 * @version 2006-07-06 Kevin Green
 */

public class GuideEdge extends DefaultEdge {
	/**
	 * Stores whether this edge is highlighted
	 */
	private boolean _isHighlighted;

	/**
	 * Creates a guide edge between a constraint vertex and a SketchNode.  The edge
	 * will default to highlighted if the node is the domain or codomain of a path
	 * of the constraint, non-highlighted otherwise.
	 *
	 * @param con the Constraint object
	 * @param node the EntityNode
	 */
	public GuideEdge(Constraint con, EntityNode node) {
		_isHighlighted = con.isDomainOrCoDomain(node);
		setSource(con.getPort());
		setTarget(node.getPort());
	}

	/**
	 * Gets whether the guide edge is highlighted or not
	 * @return true if the edge is highlighted, false otherwise
	 */
	public boolean isHighlighted(){
		return _isHighlighted;
	}

	/**
	 * Sets the edge as highlighted or not
	 * @param isHighlighted true if the edge is highlighted, false if not.
	 */
	public void setHighlighted(boolean isHighlighted){
		_isHighlighted = isHighlighted;
	}

	public String toString() {
		return "";
	}

	public AttributeMap getAttributes() {
		AttributeMap attrs = super.getAttributes();

		// A GuideEdge is never selectable
		GraphConstants.setSelectable(attrs, false);

		return attrs;
	}
}

