package easik.sketch.edge;

import easik.sketch.keys.UniqueIndexable;
import easik.sketch.vertex.EntityNode;

/**
 * A subclass of SketchEdge that identifies an edge as a normal (i.e.
 * non-injective, non-partial) edge.
 *
 * @see SketchEdge
 */
public class NormalEdge extends SketchEdge implements UniqueIndexable {
	/**
	 * Creates a new normal (i.e. non-injective, non-partial) edge between two
	 * entity nodes with the specified name and RESTRICT cascading.
	 *
	 * @param source The source entity node
	 * @param source The target entity node
	 * @param name The unique edge identifier
	 * @see SketchEdge(EntityNode, EntityNode, String)
	 * @see PartialEdge(EntityNode, EntityNode, String)
	 */
	public NormalEdge(EntityNode a, EntityNode b, String name) {
		this(a, b, name, Cascade.RESTRICT);
	}

	/**
	 * Creates a new normal (i.e. non-injective, non-partial) edge between two
	 * entity nodes with the specified name and cascading option.
	 *
	 * @param source The source entity node
	 * @param source The target entity node
	 * @param name The unique edge identifier
	 * @param cascade The cascade value, such as SketchEdge.Cascade.RESTRICT
	 * @see SketchEdge.Cascade
	 * @see SketchEdge(EntityNode, EntityNode, String)
	 * @see PartialEdge(EntityNode, EntityNode, String)
	 */
	public NormalEdge(EntityNode a, EntityNode b, String name, Cascade cascade) {
		super(a, b, name, cascade);
	}
}
