package easik.ui.datamanip;

import java.util.List;
import java.sql.*;

import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JScrollPane;
import javax.swing.JTable;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.BorderLayout;


import easik.database.*;

/**
 * JDialog set up to allow selection of records. The data being displayed is handed
 * to this class in the form of a JTable. The use 
 */
public class SelectDataDialog extends JDialog {
	boolean _ok = false;

	private JTable guiTable;

	private DatabaseDriver dbd;

	/**
	 * Sets up a data selection dialog.
	 *
	 * @param parent the parent frame of the modal dialog
	 * @param title The title of the dialog window
	 * @param table The data of the table to display
	 * @param inDBD The driver used to communicate with the database
	 */
	public SelectDataDialog(JFrame parent, String title, JTable table, DatabaseDriver inDBD) {
		super(parent, title, true);
		init(table, inDBD);
	}
	/**
	 * Sets up a data selection dialog on a dialog instead of a frame.
	 *
	 * @param parent the parent JDialog of the modal dialog
	 * @param title The title of the dialog window
	 * @param table The data of the table to display
	 * @param inDBD The driver used to communicate with the database
	 */
	public SelectDataDialog(JDialog parent, String title, JTable table, DatabaseDriver inDBD) {
		super(parent, title, true);
		init(table, inDBD);
	}

	private void init(JTable table, DatabaseDriver inDBD) {
		guiTable = table;
		guiTable.setDefaultEditor(Object.class, null);// make cells uneditable


		dbd = inDBD;

		setDefaultCloseOperation(DISPOSE_ON_CLOSE);

		final JButton ok = new JButton("OK"), cancel = new JButton("Cancel");
		getRootPane().setDefaultButton(ok);
		ok.setActionCommand("ok");
		cancel.setActionCommand("cancel");
		ButtonListener bl = new ButtonListener();
		ok.addActionListener(bl);
		cancel.addActionListener(bl);
		JPanel buttons = new JPanel();
		buttons.add(ok);
		buttons.add(cancel);

		// make double click on table fire OK button
		guiTable.addMouseListener(new MouseAdapter(){
			public void mouseClicked(MouseEvent e){
				if(e.getClickCount() > 1 && e.getButton() == MouseEvent.BUTTON1) // double click
					ok.doClick();
			}
			public void mousePressed(MouseEvent e){ mouseClicked(e); }
		});

		add(new JScrollPane(guiTable), BorderLayout.CENTER);
		add(buttons, BorderLayout.SOUTH);

		_ok = false;
		this.pack();

		this.setSize(this.getPreferredSize());

		setLocationRelativeTo(getParent());

		setVisible(true);
	}

	/**
	 * Returns true if the user accepted the options dialog (that is, clicked
	 * the OK button).
	 *
	 * @return true if the user clicked OK (and the fields verified
	 * successfully), false if the user cancelled or closed the dialog.
	 */
	public boolean isAccepted() {
		return _ok;
	}

	/**
	 * Gets the rows selected from the data table. This information can then be used by DatabaseUtils to find selected
	 * primary IDs.
	 * @return An int array of row numbers selected in the display
	 */
	public int[]  getSelectedPKs(){
		ColumnNaming cn = new ColumnNaming(dbd);
		int[] selectedRows =  guiTable.getSelectedRows();
		int[] selectedPKs = new int[selectedRows.length];
		int PKcolumn = 0; //convention for DatabaseUtil.getTable()
		for(int i=0; i<selectedRows.length; i++){
			selectedPKs[i] = Integer.parseInt((String)guiTable.getValueAt(selectedRows[i], PKcolumn));
		}
		return selectedPKs;
	}


	private class ButtonListener implements ActionListener {
		// Fired when the user clicks OK or Cancel
		public void actionPerformed(ActionEvent e){
			if (e.getActionCommand().equals("ok")) {
					_ok = true;
					SelectDataDialog.this.dispose();
			}
			else if (e.getActionCommand().equals("cancel")){
				guiTable.setCellSelectionEnabled(false);
				SelectDataDialog.this.dispose();
			}
		}
	}
}
