package easik.ui.menu;
import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;

import easik.view.View;
import easik.ui.ViewFrame;
import easik.ui.JUtils;


/**
 * The menu action for when 'new sketch' is selected
 * 
 * @author Rob Fletcher 2005
 */

public class FileClearViewAction extends AbstractAction {	

	ViewFrame _theFrame;

	/**
	 * Create a new sketch action option.	 
	 */
	public FileClearViewAction(ViewFrame inFrame) {
		super("Clear view");
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_N));
		putValue(AbstractAction.SHORT_DESCRIPTION, "Start new sketch");		
	}

	/**
	 * Create a new sketch.  Prompts user for confirmation if current sketch is unsaved.
	 * 
	 * @param e The Action Event
	 */
	public void actionPerformed(ActionEvent e) {
		boolean proceed = true;
		if ( ! _theFrame.getView().isEmpty()) {
			proceed = JUtils.confirmLoss(_theFrame);
			// we removed something from the current view, changing the overview, so set it to dirty
			if(proceed)
				_theFrame.getOverview().setDirty(true);
		}
		if (proceed) {
			View theView = _theFrame.getView();

			theView.newView();

			theView.updateThumb();
			_theFrame.getNode().setName(theView.getOverview().getNewViewName());
			theView.getOverview().refresh();
		}
	}
}
