package easik.ui.menu;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;
import java.io.File;

import javax.swing.AbstractAction;

import easik.*;
import easik.ui.*;
import easik.sketch.Sketch;
import easik.overview.vertex.SketchNode;


/** 
 * Menu action for exporting the sketch as XML
 * @author Rob Fletcher 2005
 * @author Kevin Green 2006
 * @version 2006-07-13 Kevin Green
 */

public class SketchExportAction extends AbstractAction {
	
	EasikFrame _theFrame;

	/**
	 * Create a new save as menu action.
	 */
	public SketchExportAction(EasikFrame inFrame) {
		super(inFrame instanceof SketchFrame ? "XML..." : "Export sketch to XML...");
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_A));
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Export current sketch as XML document");		
	}

	/**
	 * Display a dialog prompting the user for the name under which to save the current sketch.
	 *  
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {

		Sketch sketch;
		if(_theFrame instanceof SketchFrame){
			sketch = ((SketchFrame)_theFrame).getSketch();
		}
		else{
			Object[] currentSelection = ((ApplicationFrame)_theFrame).getOverview().getSelectionCells();
			if ( !(currentSelection.length == 1 && currentSelection[0] instanceof SketchNode) ){
				System.err.println("Sketch export via overview popup should only be enabled when " +
						"selection size is 1, and it is a sketch node");
				return;
			}
			sketch = (Sketch) ((SketchNode)currentSelection[0]).getFrame().getSketch();
		}
		File selFile = FileChooser.saveFile("Save EASIK Sketch", FileFilter.EASIK_SKETCH, "sketch");

		if (selFile != null) {	
			sketch.getDocInfo().updateModificationDate();
			sketch.saveToXML(selFile);
		}
	}
}
