package easik.ui.menu.popup;

import java.awt.Point;
import java.awt.event.ActionEvent;

import java.util.*;
import java.sql.*;

import javax.swing.AbstractAction;

import easik.database.DatabaseDriver;
import easik.sketch.Sketch;
import easik.sketch.vertex.EntityNode;
import easik.ui.datamanip.*;

/**
 * Action used by the delete row popup menu item.
 */
public class DeleteRowAction extends AbstractAction {
	/** The sketch in which the table from which we are deleting exists. */
	private Sketch _theSketch;

	/**
	 * Prepare the menu option, as well as pass a reference to the last
	 * clicked point, which is used when positioning the new entity.
	 *
	 * @param inPoint The sketch's last-rightclicked-position
	 */
	public DeleteRowAction(Sketch inSketch) {
		super("Delete row(s) from table...");
		_theSketch = inSketch;
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Display data in table to select and remove");
	}

	/**
	 * Create the new entity and set up its name
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		Object[] currentSelection = _theSketch.getSelectionCells();
		DatabaseDriver dbd;

		Object selected = currentSelection[0];
		if( ! (selected instanceof EntityNode) ){
			System.err.println("Action only available on entity nodes: easik.ui.menu.popup.DeleteRowAction");
			return;
		}

		UpdateMonitor um = _theSketch.getUpdateMonitor();
		um.deleteFrom((EntityNode)selected);
	}
}
