package easik.ui.menu.popup;

import easik.ui.JUtils;
import easik.ui.OptionsDialog;
import easik.ui.Option;
import easik.ui.SketchFrame;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JCheckBox;
import javax.swing.BoxLayout;

import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;

public class ExportOptions extends OptionsDialog {

	private SketchFrame _theFrame;

	private String _dbType;

	/*
	 * Various JThings containing entered information.
	 */
	private JCheckBox _createDatabase, _dropDatabase, _dropSchema, _bigKeys;

	/**
	 * Creates and displays a new modal database options dialog.
	 *
	 * @param driver the SQL driver type, such as "MySQL" or "PostgreSQL"
	 * @param exporting if true, export options will be collected as well, and stored
	 * 		in the exportOptions key of the map returned by getParams().
	 * @param sketchFrame the SketchFrame to attach this modal dialog box to
	 */
	public ExportOptions(String type, SketchFrame sketchFrame) {
		super(sketchFrame, "Database parameters");
		_theFrame = sketchFrame;
		_dbType = type;
		setSize(425, 350);
		showDialog();
	}

	/**
	 * Gets database connection options.  If the Sketch associated with the
	 * SketchFrame already has a driver, we use it for the defaults.
	 */
	public List<Option> getOptions() {
		LinkedList<Option> opts = new LinkedList<Option>();

		JPanel dbopts = new JPanel();
		dbopts.setLayout(new BoxLayout(dbopts, BoxLayout.Y_AXIS));
		// FIXME -- we should add some help (mouseover? help button?) to describe these in more detail

		dbopts.add(_createDatabase = new JCheckBox("Create database"));
		dbopts.add(_dropDatabase = new JCheckBox("Drop database before creating"));
		_dropDatabase.setEnabled(_createDatabase.isSelected());
		_createDatabase.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { _dropDatabase.setEnabled(_createDatabase.isSelected()); }
		});
		if (_dbType.equals("PostgreSQL")) {
			dbopts.add(_dropSchema = new JCheckBox("Drop and recreate schema"));
		}

		dbopts.add(_bigKeys = new JCheckBox("Use BIGINTs instead of INTs for keys"));
		_bigKeys.setToolTipText(JUtils.tooltip("Enabling this option will cause all primary and foreign key columns to be BIGINTs instead of INTEGERs.  Enable this if you anticipate more than 2 billion row insertions over the lifetime of the table"));

		opts.add(new Option(new JLabel("Creation options"), dbopts));

		return opts;
	}

	public Map<String, Object> getParams() {
		HashMap<String, Object> options = new HashMap<String, Object>();

		if (_createDatabase.isSelected()) {
			options.put("createDatabase", "true");
			if (_dropDatabase.isSelected())
				options.put("dropDatabase", "true");
		}

		if (_dropSchema != null && _dropSchema.isSelected())
			options.put("dropSchema", "true");

		if (_bigKeys.isSelected())
			options.put("bigKeys", "true");

		return options;
	}
}
