package easik.ui.menu.popup;

import java.awt.Point;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.sketch.Sketch;
import easik.ui.SketchFrame;

/**
 * Action for the new entity option in the popup menu.
 * 
 * @author Rob Fletcher 2005
 */
public class NewEntityAction extends AbstractAction {

	/** The frame in which the new entity will be displayed. */
	SketchFrame _theFrame;

	/** The point at which to place the new entity */
	Point _newPoint;

	/**
	 * Prepare the menu option, as well as pass a reference to the last
	 * clicked point, which is used when positioning the new entity.
	 * 
	 * @param inPoint The sketch's last-rightclicked-position
	 */
	public NewEntityAction(Point inPoint, SketchFrame inFrame) {
		super("Add entity...");
		_theFrame = inFrame;
		putValue(
				AbstractAction.SHORT_DESCRIPTION,
				"Add a new entity to the sketch");

		_newPoint = inPoint;
	}

	/**
	 * Create the new entity and set up its name
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		Sketch _ourSketch = _theFrame.getSketch();

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_ourSketch.isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}

		String newName = _ourSketch.getNewName();

		newName =
			(String) JOptionPane.showInputDialog(
					_theFrame,
					"Name for new entity:",
					"Get name",
					JOptionPane.QUESTION_MESSAGE,
					null,
					null,
					newName);
		if (newName == null || newName.trim() == null) {
			return;
		}
		newName = newName.trim();

		while(newName.equals("") || _theFrame.getSketch().isNameUsed(newName)){
			JOptionPane.showMessageDialog(
					_theFrame,
					"Error while naming entity.\n"+
					"Please ensure that entity name is:\n"+
					"1) Not blank\n"+
					"2) Not already in use",
					"Error",
					JOptionPane.ERROR_MESSAGE);
			newName =
				(String) JOptionPane.showInputDialog(
						_theFrame,
						"Name for new entity:",
						"Get name",
						JOptionPane.QUESTION_MESSAGE,
						null,
						null,
						newName);
			if (newName == null) {
				return;
			}
			newName = newName.trim();
		}
		_ourSketch.getFrame().getInfoTreeUI().storeExpansion();

		Point p = _newPoint != null ? _newPoint : _ourSketch.getNewPosition(10);

		_ourSketch.addNewEntity(newName, p.getX(), p.getY());
		_ourSketch.setDirty();
		_ourSketch.setSynced(false);
		
		_ourSketch.getFrame().getInfoTreeUI().revertExpansion();
	}
}
