package easik.ui.menu.popup;

import java.awt.Point;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.view.vertex.QueryNode;
import easik.ui.ViewFrame;
import easik.ui.DefineQueryNodeDialog;

/**
 * Action for the new query node option in the popup menu.
 * 
 * @author Rob Fletcher 2005
 */
public class NewQueryNodeAction extends AbstractAction {
	
	/** The frame in which the new entity will be displayed. */
	ViewFrame _theFrame;

	/** The point at which to place the new entity */
	Point _newPoint;

	/**
	 * Prepare the menu option, as well as pass a reference to the last
	 * clicked point, which is used when positioning the new entity.
	 * 
	 * @param inPoint The sketch's last-rightclicked-position
	 */
	public NewQueryNodeAction(Point inPoint, ViewFrame inFrame) {
		super("Add query node...");
		_theFrame = inFrame;
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Add a new query node to the view");

		_newPoint = inPoint;
	}

	/**
	 * Create the new query node.
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		String defaultName = _theFrame.getView().getNewName();
		QueryNode newNode = new QueryNode(defaultName, (int)_newPoint.getX(), (int)_newPoint.getY(), _theFrame.getView(), "");

		DefineQueryNodeDialog dqnd = new DefineQueryNodeDialog(_theFrame, "New Query Node", newNode);

		if ( ! dqnd.isAccepted() ) return;

		String name = dqnd.getName();
		String query = dqnd.getQuery();

		String errorMess = null;

		if (name.equals(""))
			errorMess = "Name cannot be blank: Node not added.";
		else if( ! query.toUpperCase().startsWith("SELECT") ){
			System.err.println("Query: '" + query + "'");
			errorMess = "Must be a SELECT query: Node not added.";
		}
		else if( _theFrame.getView().isNameUsed(name))
			errorMess = "Name currently in use: Node not added.";

		if ( errorMess != null){
			JOptionPane.showMessageDialog(
					_theFrame,
					errorMess,
					"Error",
					JOptionPane.ERROR_MESSAGE);
			return;
		}
		
		newNode.setName(name);
		newNode.setQuery(query);

		_theFrame.getView().addQueryNode(newNode);
		_theFrame.getView().setDirty();
	}
}
