package easik.ui.menu.popup;


import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.Action;

import easik.sketch.Sketch;
import easik.overview.Overview;
import easik.overview.vertex.SketchNode;


/**
 * Action for setting the frame associated with a selected sketch node visible. Sketch will be opened for editing.
 */
public class OpenSketchAction extends AbstractAction {
	/** The overview in which the action occurs */
	private Overview _theOverview;

	private static final String LABEL = "Edit sketch...";

	public OpenSketchAction(Overview inOverview){
		this(inOverview, false);
	}
	public OpenSketchAction(Overview inOverview, boolean bold) {
		super(bold ? "<html><b>" + LABEL + "</b></html>" : LABEL);
		_theOverview = inOverview;
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Open selected sketch for editing.");
	}

	/**
	 * Enable editing on selected sketch.
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e) {
		Object[] selection = _theOverview.getSelectionCells();

		for ( Object sel : selection){
			if(sel instanceof SketchNode){
				((SketchNode)sel).getFrame().enableSketchEdit();
			}
		}
		_theOverview.clearSelection();
	}

}
