package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;


import easik.ui.SketchFrame;
import easik.sketch.attribute.AttributeUI;
import easik.sketch.attribute.EntityAttribute;
import easik.sketch.vertex.EntityNode;
import easik.database.types.Type;


/**
 * Add attribute popup menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-06-14 Kevin Green
 * @version 2006-07-26 Kevin Green
 */
public class AddAttributeAction extends AbstractAction {	
	
	SketchFrame _theFrame;

	/**
	 *	Set up the add attribute menu option.
	 */
	public AddAttributeAction(SketchFrame inFrame) {
		super("Add Attribute");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Add an attribute to the currently selected entity.");		
	}
	
	/**
	 * Inserts an attribute to the currently selected entity
	 * (or parent entity if attribute is selected) in the tree
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		Object[] selected = _theFrame.getSketch().getSelectionCells();

		EntityNode curEntity;
		//Check what is currently selected
		if (selected.length == 1 && selected[0] instanceof EntityNode) {
			//Entity is selected so set it as current entity
			curEntity = (EntityNode) selected[0];
		}
		else {
			JOptionPane.showMessageDialog(_theFrame, 
					"You do not have an entity selected. \nPlease select a single entity and try again.",
					"No Entity Selected", JOptionPane.ERROR_MESSAGE);
			return;
		}

		AttributeUI myUI = new AttributeUI(_theFrame, curEntity);
		if (myUI.isAccepted()) {

			//Get values from dialog
			String newAttName = myUI.getName();
			Type newAttType = myUI.getType();

			//Create Entity Attribute
			EntityAttribute newAtt = new EntityAttribute(newAttName, newAttType, curEntity);
			//Add attribute to entity
			curEntity.addEntityAttribute(newAtt);

			_theFrame.getInfoTreeUI().refreshTree(curEntity); //Refresh view of entity

			_theFrame.getSketch().clearSelection();
			_theFrame.getSketch().setDirty();
			_theFrame.getSketch().setSynced(false);
		}
	}
}
