package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;

import easik.ui.SketchFrame;
import easik.sketch.states.*;
import easik.sketch.constraint.*;

/**
 * Show constraint menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-08-17 Kevin Green
 * @version 2006-08-17 Kevin Green
 */
public class AddPathAction extends AbstractAction {	
	
	SketchFrame _theFrame;

	/**
	 *	Set up the add path menu option.
	 */
	public AddPathAction(SketchFrame inFrame) {
		super("Add Path(s) to Constraint");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Adds a path to the currently selected constraint.");		
	}
	
	/**
	 * Pushes the add path state
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted or too many things selected then just do nothing
		if(_theFrame.getSketch().getSelectionCells().length != 1){
			return;
		}
		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		Object curSelected = _theFrame.getSketch().getSelectionCells()[0];

		//Selection is a constraint that can have a path added
		if (curSelected instanceof SumConstraint) {
			_theFrame.getSketch().getStateManager().pushState(
					new AddSumConstraintState(_theFrame.getSketch(), (SumConstraint) curSelected));
		}
		else if (curSelected instanceof CommutativeDiagram) {
			_theFrame.getSketch().getStateManager().pushState(
					new AddCommutativeDiagramState(_theFrame.getSketch(), (CommutativeDiagram) curSelected));
		}
		else if (curSelected instanceof ProductConstraint) {
			_theFrame.getSketch().getStateManager().pushState(
					new AddProductConstraintState(_theFrame.getSketch(), (ProductConstraint) curSelected));
		}
		//Selection is not a valid constraint type
		else {
			JOptionPane.showMessageDialog(_theFrame,
					"You don't have a sum, product, or commutative diagram constraint selected.\nPlease select a sum, product, or commutative diagram constraint and try again.",
					"No Constraint Selected", JOptionPane.ERROR_MESSAGE);
		}
	}
}
