package easik.ui.tree.popup;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.ViewFrame;
import easik.ui.DefineQueryNodeDialog;
import easik.view.View;
import easik.view.vertex.QueryNode;

/**
 * Action for defining a query node in a view. Opens a dialog which allows the
 * user to rename the node and define the query that it represents.
 */
public class DefineQueryNodeFromTreeAction extends AbstractAction {
		
	ViewFrame _theFrame;

	/**
	 * Sets up define query node action
	 */
	public DefineQueryNodeFromTreeAction(ViewFrame inFrame) {		
		super("Define query node...");
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_R));
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Change the name of selection");
	}

	/**
	 * Prompts user for name and query values and make appropriate updates on query node.
	 * @param node The node to be updated
	 */
	public static void updateNode(QueryNode ourNode){
		ViewFrame ourFrame = ourNode.getView().getFrame();
		View ourView = ourFrame.getView();

		String originalName = ourNode.getName();
		DefineQueryNodeDialog dqnd = new DefineQueryNodeDialog(ourFrame, "Define Query Node", ourNode);

		if ( !dqnd.isAccepted() ) return;

		String errorMess = null;
		String name = dqnd.getName();

		if (name.equals("")){
			errorMess = "Blank name field: did not update.";
		}
		else if(ourView.isNameUsed(name) && !originalName.equals(name)){
			errorMess = "Name already in use: not update.";
		}

		if (errorMess != null){
			JOptionPane.showMessageDialog( ourView.getParent(),
					errorMess,
					"Error",
					JOptionPane.ERROR_MESSAGE);
		}else if( ! name.equals(originalName)){
			ourNode.setName( name );

			ourFrame.getInfoTreeUI().refreshTree();
			ourView.getGraphLayoutCache().reload();

			ourView.repaint();
			ourView.setDirty();
		}

		String query = dqnd.getQuery();
		if ( ! query.toUpperCase().startsWith("SELECT") && ! query.equals("")){
			JOptionPane.showMessageDialog( ourView.getParent(),
					"Must enter a select query.",
					"Error",
					JOptionPane.ERROR_MESSAGE);
			ourNode.setQuery("");
		}
		else{
			ourNode.setQuery(query);
		}
		ourView.clearSelection();
	}
	
	/**
	 * Fires updateNode(QueryNode ourNode) with the current selection, should its size be equal to 1.
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		Object[] currentSelection = _theFrame.getView().getSelectionCells();

		if( currentSelection.length != 1) return;

		DefaultMutableTreeNode selected = (DefaultMutableTreeNode) _theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();
		if ( selected.getUserObject() instanceof QueryNode ){
			updateNode((QueryNode)selected.getUserObject());
		}
	}
}			
