package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.attribute.EntityAttribute;
import easik.sketch.vertex.EntityNode;


/**
 * Delete attribute popup menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-06-14 Kevin Green
 * @version 2006-07-26 Kevin Green
 */
public class DeleteAttributeAction extends AbstractAction {	
	
	SketchFrame _theFrame;

	/**
	 *	Set up the delete attribute menu option.
	 */
	public DeleteAttributeAction(SketchFrame inFrame) {
		super("Delete Attribute");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Deletes the currently selected attribute.");		
	}
	
	/**
	 * Deletes the currently selected attribute
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}
		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

		//Selection is an attribute
		if (curSelected instanceof EntityAttribute) {
			EntityAttribute curAttribute = (EntityAttribute) curSelected;
			EntityNode parentEntity = curAttribute.getEntity();

			//Show a confirmation dialog box for the deletion
			if(JOptionPane.showConfirmDialog(_theFrame,
					"Are you sure you want to delete the '" + curAttribute.getName() + 
					"' attribute from the '" + parentEntity + "' entity?",
					"Confirm Delete", JOptionPane.OK_CANCEL_OPTION)
					== JOptionPane.OK_OPTION){

				//Delete the attribute from entity
				parentEntity.removeEntityAttribute(curAttribute);

				_theFrame.getSketch().setDirty();
				_theFrame.getSketch().setSynced(false);
			}
		}
		//Selection is not an attribute
		else{ 
			JOptionPane.showMessageDialog(_theFrame,
					"You don't have an attribute selected. \nPlease select an attribute and try again.",
					"No Attribute Selected", JOptionPane.ERROR_MESSAGE);
			return;
		}

		_theFrame.getInfoTreeUI().revertExpansion();
	}
}
