package easik.ui.tree.popup;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.ApplicationFrame;
import easik.sketch.Sketch;
import easik.overview.vertex.*;

/**
 * Action for the delete entity option in the popup menu.
 * 
 * @author Kevin Green 2006
 * @since 2006-08-02 Kevin Green
 * @version 2006-08-02 Kevin Green
 */
public class DeleteFromOverviewFromTreeAction extends AbstractAction{
	
	ApplicationFrame _theFrame;

	/**
	 * Sets up delete entity action
	 */
	public DeleteFromOverviewFromTreeAction(ApplicationFrame inFrame, String label){
		super(label);	
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_D));
		putValue(AbstractAction.SHORT_DESCRIPTION, "Deletes the currently selected entity");
	}
	
	/**
	 * Called when clicked upon, will delete entity. 
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}

		int op = JOptionPane.showConfirmDialog(_theFrame, "Are you sure you want to delete the selected items?", "Confirm Deletion", JOptionPane.YES_NO_OPTION);
		if(op == JOptionPane.YES_OPTION){

			//Get currently selected object
			DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
				_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

			if(curSelected.getUserObject() instanceof SketchNode){
				_theFrame.getOverview().removeSketch((SketchNode)curSelected.getUserObject());

				_theFrame.getOverview().setDirty(true);
			}
			else{
				_theFrame.getOverview().removeView((ViewNode)curSelected.getUserObject());

				_theFrame.getOverview().setDirty(true);
			}
		}
	}
}
