package easik.ui.tree.popup;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.attribute.AttributeUI;
import easik.sketch.attribute.EntityAttribute;
import easik.sketch.vertex.EntityNode;
import easik.database.types.Type;


/**
 * Edit attribute popup menu action for the information tree.
 * 
 * @author Kevin Green 2006
 * @since 2006-06-14 Kevin Green
 * @version 2006-07-26 Kevin Green
 */
public class EditAttributeAction extends AbstractAction {	
	
	SketchFrame _theFrame;

	/**
	 *	Set up the edit attribute menu option.
	 */
	public EditAttributeAction(SketchFrame inFrame) {
		super("Edit Attribute");
		_theFrame = inFrame;
		putValue( AbstractAction.SHORT_DESCRIPTION,  "Edits the currently selected attribute.");		
	}
	
	/**
	 * Brings up a dialog to edit the currently selected attribute
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_theFrame.getSketch().isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
	
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();

		//Selection is an attribute
		if (curSelected instanceof EntityAttribute) {
			EntityAttribute curAttribute = (EntityAttribute) curSelected;
			EntityNode parentEntity = curAttribute.getEntity();

			AttributeUI myUI = new AttributeUI(_theFrame, parentEntity, curAttribute);

			if (myUI.isAccepted()) {
				// Get values from dialog
				String newAttName = myUI.getName();
				Type newAttType = myUI.getType();

				curAttribute.setName(myUI.getName());
				curAttribute.setType(myUI.getType());

				_theFrame.getInfoTreeUI().refreshTree(parentEntity);

				Object[] myCell = new Object[] {parentEntity};
				_theFrame.getSketch().getGraphLayoutCache().hideCells(myCell, true);
				_theFrame.getSketch().getGraphLayoutCache().showCells(myCell, true);
				_theFrame.getSketch().repaint();
				
				_theFrame.getSketch().setDirty();
				_theFrame.getSketch().setSynced(false);
			}			
		}
		
		//Selection is not an attribute
		else{ 
			JOptionPane.showMessageDialog(_theFrame,
					"You don't have an attribute selected. \nPlease select an attribute and try again.",
					"No Attribute Selected", JOptionPane.ERROR_MESSAGE);
		}
	}
}
