package easik.ui.tree.popup;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import easik.ui.SketchFrame;
import easik.sketch.Sketch;
import easik.sketch.vertex.EntityNode;
import easik.sketch.states.LoadingState;

/**
 * Action for the rename entity option in the popup menu.
 * 
 * @author Kevin Green 2006
 * @version 2006-07-31 Kevin Green
 */
public class RenameEntityAction extends AbstractAction {

	SketchFrame _theFrame;

	/**
	 * Sets up rename entity action
	 */
	public RenameEntityAction(SketchFrame inFrame) {		
		super("Rename Entity");	
		_theFrame = inFrame;
		putValue(AbstractAction.MNEMONIC_KEY, new Integer(KeyEvent.VK_R));
		putValue(
			AbstractAction.SHORT_DESCRIPTION,
			"Change the name of selection");
	}
	
	/**
	 * Called when clicked upon, will rename an article. 
	 * 
	 * @param e The action event
	 */
	public void actionPerformed(ActionEvent e ) {
		//If there is nothing seleceted then just do nothing
		if(_theFrame.getInfoTreeUI().getInfoTree().isSelectionEmpty())
		{
			return;
		}
		
		//Get Sketch object
		Sketch _ourSketch = _theFrame.getSketch();

		// If we're currently synced with a database, give the user the chance to cancel operation
		if(_ourSketch.isSynced()){
			int choice = JOptionPane.showConfirmDialog(_theFrame, 
					"Warning: this sketch is currently synced with a database; continue and break synchronization?", 
					"Warning!", 
					JOptionPane.OK_CANCEL_OPTION,
					JOptionPane.WARNING_MESSAGE);
			if( choice == JOptionPane.CANCEL_OPTION)
				return;
		}
		
		//Get currently selected object
		DefaultMutableTreeNode curSelected = (DefaultMutableTreeNode) 
					_theFrame.getInfoTreeUI().getInfoTree().getSelectionPath().getLastPathComponent();
		
		EntityNode nodeToRename;
		String originalName = "";
		
		//Check what is currently selected
		if(curSelected instanceof EntityNode){
			nodeToRename = (EntityNode)curSelected;
			originalName = nodeToRename.getName();
		}
		else{
			return;
		}
			
		String s = (String)JOptionPane.showInputDialog(
							_ourSketch.getParent(),
							"New name:", "Rename",
							JOptionPane.QUESTION_MESSAGE,
							null, null, originalName);
		if (s != null) {
			s = s.trim();			
			if (s.equals("")){
				JOptionPane.showMessageDialog( _theFrame,
						"Entity name is empty",
						"Error",
						JOptionPane.ERROR_MESSAGE);					
			}
			else if(_ourSketch.isNameUsed(s)){
				JOptionPane.showMessageDialog( _theFrame,
						"Entity name is already in use",
						"Error",
						JOptionPane.ERROR_MESSAGE);
			}
			else{
				//Push loading state
				_ourSketch.getStateManager().pushState(new LoadingState(_ourSketch));
				
				nodeToRename.setName( s );
				
				_theFrame.getInfoTreeUI().refreshTree();
				_theFrame.getSketch().getGraphLayoutCache().reload();
				
				//Pop state
				_ourSketch.getStateManager().popState();
				
				_ourSketch.repaint();
				_ourSketch.setDirty();
				_ourSketch.setSynced(false);
			}		
		}	
		
		_ourSketch.clearSelection();
	}	
}
