package easik.view.vertex;

import java.awt.geom.Rectangle2D;


import easik.view.View;

import org.jgraph.graph.DefaultGraphCell;
import org.jgraph.graph.GraphConstants;

/** 
 * The superclass of all nodes on the view, has a name and a coordinate.
 * 
 * @author Rob Fletcher 2005 
 */
public class ViewVertex extends DefaultGraphCell{
	/** The x and y coordinates we wish this vertex to be initially rendered at */
	protected int _initX, _initY;

	/** The name of this node */
	protected String _name;

	/** The view to which this node belongs */
	protected View _view;
	
	/**
	 * Create a blank sketch vertex, no name, and located at (0, 0)
	 */
	public ViewVertex(View inView) {
		this("", 0, 0, inView);
	}
	/**
	 * Create a vertex with basic attributes
	 * @param name Label
	 * @param x X coordinate
	 * @param y Y coordinate	 
	 */
	public ViewVertex(String name, int x, int y, View inView) {
		_initX = x;
		_initY = y;
		_name = name;
		_view = inView;
	}
	
	/**
	 * Mutator for the name field
	 * @param name The new name
	 */
	public void setName(String name) {
		_name = name;
	}
	
	/**
	 * To string method returns the name
	 * @return Current name
	 */
	public String toString() {
		return getName();
	}
	
	/**
	 * Accessor for the name field
	 * @return the name
	 */
	public String getName() {
		return _name;
	}

	/**
	 * Accessor for the view in which this vertex exists
	 */
	public View getView(){
		return _view;
	}
	
	/**
	 * Accessor for the X coordinate
	 * @return The x coordinate
	 */
	public int getX() {
		Rectangle2D bounds = GraphConstants.getBounds(getAttributes());
		if ( bounds != null )
			return (int)bounds.getX();
		else
			return _initX;
	}

	/**
	 * Accessor for the Y Coordinate 
	 * @return	The Y Coordinate
	 */
	public int getY() {
		Rectangle2D bounds = GraphConstants.getBounds(getAttributes());
		if ( bounds != null )
			return (int)bounds.getY();
		else
			return _initY;
	}	
}
