<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
<xsl:import href="globals.xsl"/>

<xsl:output method="html" encoding="iso8859-1" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" indent="yes"/>

<xsl:template match="/help">
  <html>
	<xsl:call-template name="common-head">
	  <xsl:with-param name="title"><xsl:value-of select="title"/></xsl:with-param>
	</xsl:call-template>

	<body>
	  <xsl:apply-templates mode="page-body" select="."/>
	</body>
  </html>
</xsl:template>

<xsl:template match="/help" mode="page-body">
  <xsl:param name="h1-id"/>
  <xsl:if test="title">
	<h1><xsl:if test="$h1-id"><xsl:attribute name="id"><xsl:value-of select="$h1-id"/></xsl:attribute></xsl:if><xsl:value-of select="title"/></h1>
  </xsl:if>
  <xsl:if test="description">
	<div class="description"><xsl:apply-templates mode="html" select="description/node()"/></div>
  </xsl:if>
  <xsl:apply-templates/>
</xsl:template>


<xsl:template match="section">
  <xsl:param name="section-level">2</xsl:param><!-- The level of the section; 2 is the default, an ordinary section -->
  <div>
	<xsl:attribute name="class">
	  section
	  <xsl:if test="@clear">clear-<xsl:value-of select="@clear"/></xsl:if>
	</xsl:attribute>
	<xsl:element name="h{$section-level}">
	  <!-- If the <section></section> has an id attribute, copy it to the h2 -->
	  <xsl:if test="@id">
		<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
		<a name="{@id}"/>
	  </xsl:if>
	  <xsl:value-of select="@title"/>
	</xsl:element>
	<xsl:for-each select="*">
	  <!-- We support a special <image></image> tag; it will be converted into a special
	  image block, with the body of the tag forming the caption of the image.  Also, as
	  long as it doesn't contain a /, we prepend '../images/' to the src attribute.
	  -->
	  <xsl:choose>
		<xsl:when test="local-name() = 'image'">
		  <div class="image">
			<div class="image-container">
			  <img>
				<xsl:for-each select="@*">
				  <xsl:choose>
					<xsl:when test="local-name() = 'src' and not(contains(., '/'))">
					  <xsl:attribute name="src">../images/<xsl:value-of select="."/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
					  <xsl:copy/>
					</xsl:otherwise>
				  </xsl:choose>
				</xsl:for-each>
			  </img>
			</div>
			<div class="caption">
			  <xsl:apply-templates mode="html" select="node()"/>
			</div>
		  </div>
		</xsl:when>
		<xsl:when test="local-name() = 'section'">
		  <xsl:apply-templates select=".">
			<xsl:with-param name="section-level" select="number($section-level) + 1"/>
		  </xsl:apply-templates>
		</xsl:when>
		<xsl:otherwise>
		  <xsl:apply-templates mode="html" select="."/>
		</xsl:otherwise>
	  </xsl:choose>
	</xsl:for-each>
  </div>
</xsl:template>

<!-- Anything unrecognized should just be ignored: -->
<xsl:template match="*"/>

</xsl:stylesheet>
<!-- vim:sw=2
-->
